from distutils.core import setup
setup(
    name='django-core-waili',
    version='0.1.2',
    description='django core utils',
    author='linxuedong',
    author_email='xuedonglin1994@gmail.com',
    url='https://github.com/linxuedong/django-core',
    py_modules=['django-core-waili'],
)
